﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms;
using Microsoft.WindowsAPICodePack.Dialogs;
using System.IO;

namespace SortFiles
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();

            messageHook = WriteMessage_Internal;
        }

        /// <summary>
        /// Standard date format. This just specifies how dates are represented in the status log.
        /// https://msdn.microsoft.com/en-us/library/zdtaw1bw(v=vs.110).aspx
        /// y = year, M = month, d = day, H = hour, m = minute, s = seconds, f = milliseconds
        /// </summary>
        public const string cStandardDateFormat = "yyyy-MM-dd HH:mm:ss.ffff";

        private static void StatusMessage(string message)
        {
            if (messageHook != null)
            {
                messageHook(message);
            }
        }

        private static Action<string> messageHook;

        private void WriteMessage_Internal(string message)
        {
            string messageLine = $"{DateTime.Now.ToString(cStandardDateFormat)} : {message}{Environment.NewLine}";
            rtbMessages.AppendText(messageLine);
        }

        private void btnChooseDirectory_Click(object sender, EventArgs e)
        {
            string folderPath;

            // The reason why I brought in the Windows API code pack file browser is that it is way,
            // way easier to use than the standard folder picker. It gives you a more traditional file browser
            // setup instead of that terrible treeview thing.
            using (CommonOpenFileDialog dlgFolderPicker = new CommonOpenFileDialog())
            {
                dlgFolderPicker.IsFolderPicker = true;

                CommonFileDialogResult result = dlgFolderPicker.ShowDialog();

                if (result != CommonFileDialogResult.Ok)
                {
                    return;
                }

                folderPath = dlgFolderPicker.FileName;
            }

            SortFiles(folderPath);
        }

        private static void SortFiles(string directoryToSort)
        {
            StatusMessage("Put the file sorting code here.");
            return;
            
        }

    }
}
